You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by pu...@apache.org on 2012/02/22 09:15:23 UTC

[26/29] wp7 commit: stage 1 - bulk rename

stage 1 - bulk rename


Project: http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/commit/552bc14a
Tree: http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/tree/552bc14a
Diff: http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/diff/552bc14a

Branch: refs/heads/master
Commit: 552bc14a49e18ead0aba89f59582e16d97702afa
Parents: 5c2310e
Author: Jesse MacFadyen <pu...@gmail.com>
Authored: Thu Feb 9 15:33:09 2012 -0800
Committer: Jesse MacFadyen <pu...@gmail.com>
Committed: Thu Feb 9 15:33:09 2012 -0800

----------------------------------------------------------------------
 framework/PGView.xaml.cs                      |   16 +-
 framework/PhoneGap/CommandFactory.cs          |    8 +-
 framework/PhoneGap/Commands/Accelerometer.cs  |    2 +-
 framework/PhoneGap/Commands/AudioPlayer.cs    |    4 +-
 framework/PhoneGap/Commands/BaseCommand.cs    |    6 +-
 framework/PhoneGap/Commands/Camera.cs         |    2 +-
 framework/PhoneGap/Commands/Capture.cs        |    8 +-
 framework/PhoneGap/Commands/Compass.cs        |    2 +-
 framework/PhoneGap/Commands/Connection.cs     |    2 +-
 framework/PhoneGap/Commands/Contacts.cs       |    2 +-
 framework/PhoneGap/Commands/DebugConsole.cs   |    2 +-
 framework/PhoneGap/Commands/Device.cs         |    4 +-
 framework/PhoneGap/Commands/File.cs           |    2 +-
 framework/PhoneGap/Commands/FileTransfer.cs   |    2 +-
 framework/PhoneGap/Commands/GeoLocation.cs    |    2 +-
 framework/PhoneGap/Commands/Media.cs          |    2 +-
 framework/PhoneGap/Commands/MimeTypeMapper.cs |    2 +-
 framework/PhoneGap/Commands/Notification.cs   |   84 ++--
 framework/PhoneGap/DOMStorageHelper.cs        |    2 +-
 framework/PhoneGap/JSON/JsonHelper.cs         |    2 +-
 framework/PhoneGap/NativeExecution.cs         |   10 +-
 framework/PhoneGap/OrientationHelper.cs       |    6 +-
 framework/PhoneGap/PhoneGapCommandCall.cs     |   18 +-
 framework/PhoneGap/PluginResult.cs            |    2 +-
 framework/PhoneGap/ScriptCallback.cs          |    6 +-
 framework/PhoneGap/UI/AudioCaptureTask.cs     |    6 +-
 framework/PhoneGap/UI/AudioRecorder.xaml.cs   |    4 +-
 framework/PhoneGap/UI/VideoCaptureTask.cs     |    6 +-
 framework/PhoneGap/UI/VideoRecorder.xaml.cs   |    4 +-
 framework/js/accelerometer.js                 |   14 +-
 framework/js/battery.js                       |    6 +-
 framework/js/camera.js                        |    8 +-
 framework/js/capture.js                       |   16 +-
 framework/js/compass.js                       |   14 +-
 framework/js/contact.js                       |   14 +-
 framework/js/debugConsole.js                  |   14 +-
 framework/js/device.js                        |   14 +-
 framework/js/file.js                          |   56 ++--
 framework/js/filetransfer.js                  |    6 +-
 framework/js/media.js                         |   42 +-
 framework/js/network.js                       |   20 +-
 framework/js/notification.js                  |   24 +-
 framework/js/phonegap-1.4.1-core.js           |  386 ++++++++--------
 framework/js/phonegap-1.4.1.js                |  494 ++++++++++----------
 44 files changed, 673 insertions(+), 673 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PGView.xaml.cs
----------------------------------------------------------------------
diff --git a/framework/PGView.xaml.cs b/framework/PGView.xaml.cs
index 1970687..f85dc26 100644
--- a/framework/PGView.xaml.cs
+++ b/framework/PGView.xaml.cs
@@ -31,10 +31,10 @@ using System.Runtime.Serialization.Json;
 using System.IO;
 using System.ComponentModel;
 using System.Xml.Linq;
-using WP7GapClassLib.PhoneGap.Commands;
+using WP7GapClassLib.Cordova.Commands;
 using System.Diagnostics;
 using System.Text;
-using WP7GapClassLib.PhoneGap;
+using WP7GapClassLib.Cordova;
 using System.Threading;
 using Microsoft.Phone.Shell;
 
@@ -149,7 +149,7 @@ namespace WP7GapClassLib
 
             try
             {
-                GapBrowser.InvokeScript("PhoneGapCommandResult", new string[] { "pause" });
+                GapBrowser.InvokeScript("CordovaCommandResult", new string[] { "pause" });
             }
             catch (Exception)
             {
@@ -167,7 +167,7 @@ namespace WP7GapClassLib
             Debug.WriteLine("AppActivated");
             try
             {
-                GapBrowser.InvokeScript("PhoneGapCommandResult", new string[] { "resume" });
+                GapBrowser.InvokeScript("CordovaCommandResult", new string[] { "resume" });
             }
             catch (Exception)
             {
@@ -308,7 +308,7 @@ namespace WP7GapClassLib
             {
                 try
                 {
-                    GapBrowser.InvokeScript("PhoneGapCommandResult", new string[] { "backbutton" });
+                    GapBrowser.InvokeScript("CordovaCommandResult", new string[] { "backbutton" });
                     e.Cancel = true;
                 }
                 catch (Exception)
@@ -356,8 +356,8 @@ namespace WP7GapClassLib
                 this.orientationHelper.HandleCommand(commandStr);
                 return;
             }
-
-            PhoneGapCommandCall commandCallParams = PhoneGapCommandCall.Parse(commandStr);
+
+            CordovaCommandCall commandCallParams = CordovaCommandCall.Parse(commandStr);
 
             if (commandCallParams == null)
             {
@@ -369,7 +369,7 @@ namespace WP7GapClassLib
                 switch (commandCallParams.Action.ToLower())
                 {
                     case "overridebackbutton":
-                        string[] args = PhoneGap.JSON.JsonHelper.Deserialize<string[]>(commandCallParams.Args);
+                        string[] args = Cordova.JSON.JsonHelper.Deserialize<string[]>(commandCallParams.Args);
                         this.OverrideBackButton = (args != null && args.Length > 0 && args[0] == "true");
                         break;
                 }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/CommandFactory.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/CommandFactory.cs b/framework/PhoneGap/CommandFactory.cs
index 512a8f3..3518981 100644
--- a/framework/PhoneGap/CommandFactory.cs
+++ b/framework/PhoneGap/CommandFactory.cs
@@ -23,11 +23,11 @@ using System.Windows.Media;
 using System.Windows.Media.Animation;
 using System.Windows.Shapes;
 using System.Collections.Generic;
-using WP7GapClassLib.PhoneGap.Commands;
+using WP7GapClassLib.Cordova.Commands;
 using System.Reflection;
 using System.Diagnostics;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
     /// <summary>
     /// Provides functionality to create phone gap command by name.
@@ -37,9 +37,9 @@ namespace WP7GapClassLib.PhoneGap
         /// <summary>
         /// Represents predefined namespace name for custom plugins
         /// </summary>
-        private static readonly string CustomPluginNamespacePrefix = "PhoneGap.Extension.Commands.";
+        private static readonly string CustomPluginNamespacePrefix = "Cordova.Extension.Commands.";
 
-        private static readonly string BaseCommandNamespacePrefix  = "WP7GapClassLib.PhoneGap.Commands.";
+        private static readonly string BaseCommandNamespacePrefix  = "WP7GapClassLib.Cordova.Commands.";
 
         /// <summary>
         /// Performance optimization allowing more faster create already known commands.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Accelerometer.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Accelerometer.cs b/framework/PhoneGap/Commands/Accelerometer.cs
index df851a7..8c39780 100644
--- a/framework/PhoneGap/Commands/Accelerometer.cs
+++ b/framework/PhoneGap/Commands/Accelerometer.cs
@@ -20,7 +20,7 @@ using System.Threading;
 using Microsoft.Devices.Sensors;
 using System.Globalization;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// Captures device motion in the x, y, and z direction.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/AudioPlayer.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/AudioPlayer.cs b/framework/PhoneGap/Commands/AudioPlayer.cs
index e8796be..dcdc5ec 100644
--- a/framework/PhoneGap/Commands/AudioPlayer.cs
+++ b/framework/PhoneGap/Commands/AudioPlayer.cs
@@ -23,7 +23,7 @@ using Microsoft.Xna.Framework.Audio;
 using Microsoft.Xna.Framework.Media;
 using Microsoft.Phone.Controls;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {    
     /// <summary>
     /// Implements audio record and play back functionality.
@@ -55,7 +55,7 @@ namespace WP7GapClassLib.PhoneGap.Commands
         private const int MediaErrorPauseState = 7;
         private const int MediaErrorStopState = 8;
 
-        private const string CallbackFunction = "PhoneGapMediaonStatus";
+        private const string CallbackFunction = "CordovaMediaonStatus";
 
         #endregion
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/BaseCommand.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/BaseCommand.cs b/framework/PhoneGap/Commands/BaseCommand.cs
index a7a2641..5e82501 100644
--- a/framework/PhoneGap/Commands/BaseCommand.cs
+++ b/framework/PhoneGap/Commands/BaseCommand.cs
@@ -13,12 +13,12 @@
 */
 
 using System;
-using System.Reflection;
+using System.Reflection;
 using Microsoft.Phone.Shell;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
-    public abstract class BaseCommand : IDisposable
+    public abstract class BaseCommand : IDisposable
     {
         /*
          *  All commands + plugins must extend BaseCommand, because they are dealt with as BaseCommands in PGView.xaml.cs

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Camera.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Camera.cs b/framework/PhoneGap/Commands/Camera.cs
index 7bc0155..817cb31 100644
--- a/framework/PhoneGap/Commands/Camera.cs
+++ b/framework/PhoneGap/Commands/Camera.cs
@@ -29,7 +29,7 @@ using System.IO.IsolatedStorage;
 using System.Windows.Media.Imaging;
 using Microsoft.Phone;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     public class Camera : BaseCommand
     {

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Capture.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Capture.cs b/framework/PhoneGap/Commands/Capture.cs
index 31a6baf..c600747 100644
--- a/framework/PhoneGap/Commands/Capture.cs
+++ b/framework/PhoneGap/Commands/Capture.cs
@@ -21,11 +21,11 @@ using System.Windows.Media.Imaging;
 using Microsoft.Phone;
 using Microsoft.Phone.Tasks;
 using Microsoft.Xna.Framework.Media;
-using WP7GapClassLib.PhoneGap.UI;
-using AudioResult = WP7GapClassLib.PhoneGap.UI.AudioCaptureTask.AudioResult;
-using VideoResult = WP7GapClassLib.PhoneGap.UI.VideoCaptureTask.VideoResult;
+using WP7GapClassLib.Cordova.UI;
+using AudioResult = WP7GapClassLib.Cordova.UI.AudioCaptureTask.AudioResult;
+using VideoResult = WP7GapClassLib.Cordova.UI.VideoCaptureTask.VideoResult;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// Provides access to the audio, image, and video capture capabilities of the device

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Compass.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Compass.cs b/framework/PhoneGap/Commands/Compass.cs
index d8d8848..f0dd842 100644
--- a/framework/PhoneGap/Commands/Compass.cs
+++ b/framework/PhoneGap/Commands/Compass.cs
@@ -31,7 +31,7 @@ using System.Globalization;
 using System.Threading;
 using Microsoft.Devices.Sensors;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
 
     public class Compass : BaseCommand

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Connection.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Connection.cs b/framework/PhoneGap/Commands/Connection.cs
index 8406e58..635e4e1 100644
--- a/framework/PhoneGap/Commands/Connection.cs
+++ b/framework/PhoneGap/Commands/Connection.cs
@@ -24,7 +24,7 @@ using System.Windows.Media.Animation;
 using System.Windows.Shapes;
 using Microsoft.Phone.Net.NetworkInformation;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
 
     // http://msdn.microsoft.com/en-us/library/microsoft.phone.net.networkinformation(v=VS.92).aspx

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Contacts.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Contacts.cs b/framework/PhoneGap/Commands/Contacts.cs
index 849b87a..575233d 100644
--- a/framework/PhoneGap/Commands/Contacts.cs
+++ b/framework/PhoneGap/Commands/Contacts.cs
@@ -32,7 +32,7 @@ using System.Diagnostics;
 using System.Linq;
 
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     [DataContract]
     public class SearchOptions

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/DebugConsole.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/DebugConsole.cs b/framework/PhoneGap/Commands/DebugConsole.cs
index 5f14e59..9478a8d 100644
--- a/framework/PhoneGap/Commands/DebugConsole.cs
+++ b/framework/PhoneGap/Commands/DebugConsole.cs
@@ -24,7 +24,7 @@ using System.Windows.Media.Animation;
 using System.Windows.Shapes;
 using System.Diagnostics;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
 
     public class DebugConsole : BaseCommand

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Device.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/File.cs b/framework/PhoneGap/Commands/File.cs
index f79fff3..8bf37c3 100644
--- a/framework/PhoneGap/Commands/File.cs
+++ b/framework/PhoneGap/Commands/File.cs
@@ -20,7 +20,7 @@ using System.Runtime.Serialization;
 using System.Security;
 using System.Text;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// Provides access to isolated storage

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/FileTransfer.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/FileTransfer.cs b/framework/PhoneGap/Commands/FileTransfer.cs
index f4b1bf4..527521e 100644
--- a/framework/PhoneGap/Commands/FileTransfer.cs
+++ b/framework/PhoneGap/Commands/FileTransfer.cs
@@ -20,7 +20,7 @@ using System.Net;
 using System.Runtime.Serialization;
 using System.Windows;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     public class FileTransfer : BaseCommand
     {                

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/GeoLocation.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/GeoLocation.cs b/framework/PhoneGap/Commands/GeoLocation.cs
index a14ccfb..545fc46 100644
--- a/framework/PhoneGap/Commands/GeoLocation.cs
+++ b/framework/PhoneGap/Commands/GeoLocation.cs
@@ -18,7 +18,7 @@ using System.Runtime.Serialization;
 using System.Threading;
 using System.Device.Location;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// This is a command stub, the browser provides the correct implementation.  We use this to trigger the static analyzer that we require this permission 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Media.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Media.cs b/framework/PhoneGap/Commands/Media.cs
index ad32707..d9539fb 100644
--- a/framework/PhoneGap/Commands/Media.cs
+++ b/framework/PhoneGap/Commands/Media.cs
@@ -17,7 +17,7 @@ using System.Collections.Generic;
 using System.Runtime.Serialization;
 using System.Windows;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// Provides the ability to record and play back audio files on a device. 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/MimeTypeMapper.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/MimeTypeMapper.cs b/framework/PhoneGap/Commands/MimeTypeMapper.cs
index 3881ec6..3493b98 100644
--- a/framework/PhoneGap/Commands/MimeTypeMapper.cs
+++ b/framework/PhoneGap/Commands/MimeTypeMapper.cs
@@ -15,7 +15,7 @@
 using System.Collections.Generic;
 using System.IO;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     /// <summary>
     /// Represents file extension to mime type mapper.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/Notification.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/Commands/Notification.cs b/framework/PhoneGap/Commands/Notification.cs
index 4bf5a42..44f27f9 100644
--- a/framework/PhoneGap/Commands/Notification.cs
+++ b/framework/PhoneGap/Commands/Notification.cs
@@ -10,31 +10,31 @@
 	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 	See the License for the specific language governing permissions and
 	limitations under the License.
-*/
-
+*/
+
 using System;
-using System.Windows;
+using System.Windows;
 using System.Windows.Controls;
 using Microsoft.Devices;
 using System.Runtime.Serialization;
 using System.Threading;
 using System.Windows.Resources;
 using Microsoft.Phone.Controls;
-using Microsoft.Xna.Framework.Audio;
-
-namespace WP7GapClassLib.PhoneGap.Commands
-{
-    public class Notification : BaseCommand
+using Microsoft.Xna.Framework.Audio;
+
+namespace WP7GapClassLib.Cordova.Commands
+{
+    public class Notification : BaseCommand
     {
-        static ProgressBar progressBar = null;
-        const int DEFAULT_DURATION = 5;
-
-        // alert, confirm, blink, vibrate, beep
-        // blink api - doesn't look like there is an equivalent api we can use...
-        // vibrate api - http://msdn.microsoft.com/en-us/library/microsoft.devices.vibratecontroller(v=VS.92).aspx
-        // beep api - can probably use: http://msdn.microsoft.com/en-us/library/microsoft.phone.scheduler.alarm(v=VS.92).aspx
-        //          - examples of alarm class http://mkdot.net/blogs/filip/archive/2011/06/06/windows-phone-multitasking-part-2-2.aspx
-
+        static ProgressBar progressBar = null;
+        const int DEFAULT_DURATION = 5;
+
+        // alert, confirm, blink, vibrate, beep
+        // blink api - doesn't look like there is an equivalent api we can use...
+        // vibrate api - http://msdn.microsoft.com/en-us/library/microsoft.devices.vibratecontroller(v=VS.92).aspx
+        // beep api - can probably use: http://msdn.microsoft.com/en-us/library/microsoft.phone.scheduler.alarm(v=VS.92).aspx
+        //          - examples of alarm class http://mkdot.net/blogs/filip/archive/2011/06/06/windows-phone-multitasking-part-2-2.aspx
+
         //MessageBoxResult res = MessageBox.Show("Could not call script: " + ex.Message, "caption", MessageBoxButton.OKCancel);
 
         [DataContract]
@@ -66,20 +66,20 @@ namespace WP7GapClassLib.PhoneGap.Commands
             /// </summary>
             [DataMember]
             public string buttonLabel;
-        }
-
-        public void alert(string options)
+        }
+
+        public void alert(string options)
         {
-            Deployment.Current.Dispatcher.BeginInvoke(() =>
+            Deployment.Current.Dispatcher.BeginInvoke(() =>
             {
                 AlertOptions alertOpts = JSON.JsonHelper.Deserialize<AlertOptions>(options);
-                MessageBoxResult res = MessageBox.Show(alertOpts.message, alertOpts.title,MessageBoxButton.OK);
-
+                MessageBoxResult res = MessageBox.Show(alertOpts.message, alertOpts.title,MessageBoxButton.OK);
+
                 DispatchCommandResult(new PluginResult(PluginResult.Status.OK,(int)res));
-            });
+            });
         }
 
-        public void confirm(string options)
+        public void confirm(string options)
         {
             Deployment.Current.Dispatcher.BeginInvoke(() =>
             {
@@ -87,10 +87,10 @@ namespace WP7GapClassLib.PhoneGap.Commands
 
                 MessageBoxResult res = MessageBox.Show(alertOpts.message, alertOpts.title, MessageBoxButton.OKCancel);
                 DispatchCommandResult(new PluginResult(PluginResult.Status.OK, (int)res));
-            });
-        }
-
-        public void beep(string count)
+            });
+        }
+
+        public void beep(string count)
         {
             int times = int.Parse(count);
 
@@ -112,9 +112,9 @@ namespace WP7GapClassLib.PhoneGap.Commands
                });
 
             }
-         
-            // TODO: may need a listener to trigger DispatchCommandResult after the alarm has finished executing...
-            DispatchCommandResult();
+         
+            // TODO: may need a listener to trigger DispatchCommandResult after the alarm has finished executing...
+            DispatchCommandResult();
         }
 
         // Display an inderminate progress indicator
@@ -175,9 +175,9 @@ namespace WP7GapClassLib.PhoneGap.Commands
                     progressBar = null;
                 }
             });
-        }
-
-        public void vibrate(string vibrateDuration)
+        }
+
+        public void vibrate(string vibrateDuration)
         {
             int msecs = 200; // set default
 
@@ -194,10 +194,10 @@ namespace WP7GapClassLib.PhoneGap.Commands
 
             }
 
-            VibrateController.Default.Start(TimeSpan.FromMilliseconds(msecs));
-
-            // TODO: may need to add listener to trigger DispatchCommandResult when the vibration ends...
-            DispatchCommandResult();
-        }
-    }
-}
+            VibrateController.Default.Start(TimeSpan.FromMilliseconds(msecs));
+
+            // TODO: may need to add listener to trigger DispatchCommandResult when the vibration ends...
+            DispatchCommandResult();
+        }
+    }
+}

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/DOMStorageHelper.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/DOMStorageHelper.cs b/framework/PhoneGap/DOMStorageHelper.cs
index 5581a26..987d8ab 100644
--- a/framework/PhoneGap/DOMStorageHelper.cs
+++ b/framework/PhoneGap/DOMStorageHelper.cs
@@ -26,7 +26,7 @@ using System.IO.IsolatedStorage;
 using System.Collections.Generic;
 using Microsoft.Phone.Controls;
 using System.Linq;
-using WP7GapClassLib.PhoneGap.JSON;
+using WP7GapClassLib.Cordova.JSON;
 
 /*
  * Translates DOMStorage API between JS and Isolated Storage

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/JSON/JsonHelper.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/JSON/JsonHelper.cs b/framework/PhoneGap/JSON/JsonHelper.cs
index d66f0b0..bf5a401 100644
--- a/framework/PhoneGap/JSON/JsonHelper.cs
+++ b/framework/PhoneGap/JSON/JsonHelper.cs
@@ -27,7 +27,7 @@ using System.IO;
 using System.Collections.Generic;
 using System.Text;
 
-namespace WP7GapClassLib.PhoneGap.JSON
+namespace WP7GapClassLib.Cordova.JSON
 {
     /// <summary>
     /// Provides JSON serialization/deserialization functionality.

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/NativeExecution.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/NativeExecution.cs b/framework/PhoneGap/NativeExecution.cs
index b0c37f0..720d3f9 100644
--- a/framework/PhoneGap/NativeExecution.cs
+++ b/framework/PhoneGap/NativeExecution.cs
@@ -17,9 +17,9 @@ using System.Diagnostics;
 using System.Threading;
 using Microsoft.Devices;
 using Microsoft.Phone.Controls;
-using WP7GapClassLib.PhoneGap.Commands;
+using WP7GapClassLib.Cordova.Commands;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
     /// <summary>
     /// Implements logic to execute native command and return result back.
@@ -59,7 +59,7 @@ namespace WP7GapClassLib.PhoneGap
         /// Executes command and returns result back.
         /// </summary>
         /// <param name="commandCallParams">Command to execute</param>
-        public void ProcessCommand(PhoneGapCommandCall commandCallParams)
+        public void ProcessCommand(CordovaCommandCall commandCallParams)
         {
 
             if (commandCallParams == null)
@@ -160,11 +160,11 @@ namespace WP7GapClassLib.PhoneGap
 
             if (String.IsNullOrEmpty(result.Cast))
             {
-                scriptCallback = new ScriptCallback("PhoneGapCommandResult", new string[] { status, callbackId, jsonResult });
+                scriptCallback = new ScriptCallback("CordovaCommandResult", new string[] { status, callbackId, jsonResult });
             }
             else
             {
-                scriptCallback = new ScriptCallback("PhoneGapCommandResult", new string[] { status, callbackId, jsonResult, result.Cast });
+                scriptCallback = new ScriptCallback("CordovaCommandResult", new string[] { status, callbackId, jsonResult, result.Cast });
             }
 
             this.InvokeScriptCallback(scriptCallback);

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/OrientationHelper.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/OrientationHelper.cs b/framework/PhoneGap/OrientationHelper.cs
index 4d8df3d..5631c93 100644
--- a/framework/PhoneGap/OrientationHelper.cs
+++ b/framework/PhoneGap/OrientationHelper.cs
@@ -24,7 +24,7 @@ using System.Windows.Media.Animation;
 using System.Windows.Shapes;
 using Microsoft.Phone.Controls;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
     public class OrientationHelper
     {
@@ -65,7 +65,7 @@ namespace WP7GapClassLib.PhoneGap
                     i = 90;
                     break;
             }
-            // PhoneGap.fireEvent('orientationchange', window);
+            // Cordova.fireEvent('orientationchange', window);
             string jsCallback = String.Format("window.orientation = {0};", i);
 
             try
@@ -98,7 +98,7 @@ namespace WP7GapClassLib.PhoneGap
                     i = 90;
                     break;
             }
-            // PhoneGap.fireEvent('orientationchange', window);
+            // Cordova.fireEvent('orientationchange', window);
             string jsCallback = String.Format("window.orientation = {0};", i);
 
             try

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/PhoneGapCommandCall.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/PluginResult.cs b/framework/PhoneGap/PluginResult.cs
index aa01b76..ce55703 100644
--- a/framework/PhoneGap/PluginResult.cs
+++ b/framework/PhoneGap/PluginResult.cs
@@ -25,7 +25,7 @@ using System.Windows.Shapes;
 using System.Text;
 using System.Diagnostics;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
 	/// <summary>
 	/// Represents command execution result

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/ScriptCallback.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/ScriptCallback.cs b/framework/PhoneGap/ScriptCallback.cs
index 079cb41..900954a 100644
--- a/framework/PhoneGap/ScriptCallback.cs
+++ b/framework/PhoneGap/ScriptCallback.cs
@@ -1,5 +1,5 @@
 /*
- * PhoneGap is available under *either* the terms of the modified BSD license *or* the
+ * Cordova is available under *either* the terms of the modified BSD license *or* the
  * MIT License (2008). See http://opensource.org/licenses/alphabetical for full text.
  *
  * Copyright (c) 2005-2011, Nitobi Software Inc.
@@ -16,9 +16,9 @@ using System.Windows.Input;
 using System.Windows.Media;
 using System.Windows.Media.Animation;
 using System.Windows.Shapes;
-using WP7GapClassLib.PhoneGap.JSON;
+using WP7GapClassLib.Cordova.JSON;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
     /// <summary>
     /// Represents client script function to execute

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/UI/AudioCaptureTask.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/UI/AudioCaptureTask.cs b/framework/PhoneGap/UI/AudioCaptureTask.cs
index c9bae7c..dad7f1b 100644
--- a/framework/PhoneGap/UI/AudioCaptureTask.cs
+++ b/framework/PhoneGap/UI/AudioCaptureTask.cs
@@ -18,7 +18,7 @@ using System.Windows;
 using Microsoft.Phone.Controls;
 using Microsoft.Phone.Tasks;
 
-namespace WP7GapClassLib.PhoneGap.UI
+namespace WP7GapClassLib.Cordova.UI
 {
     /// <summary>
     /// Allows an application to launch the Audio Recording application. 
@@ -28,7 +28,7 @@ namespace WP7GapClassLib.PhoneGap.UI
     {
         /// <summary>
         /// Represents recorded audio returned from a call to the Show method of
-        /// a WP7GapClassLib.PhoneGap.Controls.AudioCaptureTask object
+        /// a WP7GapClassLib.Cordova.Controls.AudioCaptureTask object
         /// </summary>
         public class AudioResult : TaskEventArgs
         {
@@ -75,7 +75,7 @@ namespace WP7GapClassLib.PhoneGap.UI
                 root.Navigated += new System.Windows.Navigation.NavigatedEventHandler(NavigationService_Navigated);
 
                 // dummy parameter is used to always open a fresh version
-                root.Navigate(new System.Uri("/WP7GapClassLib;component/PhoneGap/UI/AudioRecorder.xaml?dummy=" + Guid.NewGuid().ToString(), UriKind.Relative));
+                root.Navigate(new System.Uri("/WP7GapClassLib;component/Cordova/UI/AudioRecorder.xaml?dummy=" + Guid.NewGuid().ToString(), UriKind.Relative));
             });
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/UI/AudioRecorder.xaml.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/UI/AudioRecorder.xaml.cs b/framework/PhoneGap/UI/AudioRecorder.xaml.cs
index e6d54c8..73fe016 100644
--- a/framework/PhoneGap/UI/AudioRecorder.xaml.cs
+++ b/framework/PhoneGap/UI/AudioRecorder.xaml.cs
@@ -21,9 +21,9 @@ using Microsoft.Phone.Controls;
 using Microsoft.Phone.Tasks;
 using Microsoft.Xna.Framework;
 using Microsoft.Xna.Framework.Audio;
-using AudioResult = WP7GapClassLib.PhoneGap.UI.AudioCaptureTask.AudioResult;
+using AudioResult = WP7GapClassLib.Cordova.UI.AudioCaptureTask.AudioResult;
 
-namespace WP7GapClassLib.PhoneGap.UI
+namespace WP7GapClassLib.Cordova.UI
 {
     /// <summary>
     /// Implements Audio Recording application

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/UI/VideoCaptureTask.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/UI/VideoCaptureTask.cs b/framework/PhoneGap/UI/VideoCaptureTask.cs
index 65ca07f..a954a2a 100644
--- a/framework/PhoneGap/UI/VideoCaptureTask.cs
+++ b/framework/PhoneGap/UI/VideoCaptureTask.cs
@@ -18,7 +18,7 @@ using System.Windows;
 using Microsoft.Phone.Controls;
 using Microsoft.Phone.Tasks;
 
-namespace WP7GapClassLib.PhoneGap.UI
+namespace WP7GapClassLib.Cordova.UI
 {
     /// <summary>
     /// Allows an application to launch the Video Recording application. 
@@ -28,7 +28,7 @@ namespace WP7GapClassLib.PhoneGap.UI
     {
         /// <summary>
         /// Represents recorded video returned from a call to the Show method of
-        /// a WP7GapClassLib.PhoneGap.Controls.VideoCaptureTask object
+        /// a WP7GapClassLib.Cordova.Controls.VideoCaptureTask object
         /// </summary>
         public class VideoResult : TaskEventArgs
         {
@@ -75,7 +75,7 @@ namespace WP7GapClassLib.PhoneGap.UI
                 root.Navigated += new System.Windows.Navigation.NavigatedEventHandler(NavigationService_Navigated);
 
                 // dummy parameter is used to always open a fresh version
-                root.Navigate(new System.Uri("/WP7GapClassLib;component/PhoneGap/UI/VideoRecorder.xaml?dummy=" + Guid.NewGuid().ToString(), UriKind.Relative));
+                root.Navigate(new System.Uri("/WP7GapClassLib;component/Cordova/UI/VideoRecorder.xaml?dummy=" + Guid.NewGuid().ToString(), UriKind.Relative));
             });
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/UI/VideoRecorder.xaml.cs
----------------------------------------------------------------------
diff --git a/framework/PhoneGap/UI/VideoRecorder.xaml.cs b/framework/PhoneGap/UI/VideoRecorder.xaml.cs
index 0912ad9..96961d5 100644
--- a/framework/PhoneGap/UI/VideoRecorder.xaml.cs
+++ b/framework/PhoneGap/UI/VideoRecorder.xaml.cs
@@ -20,9 +20,9 @@ using System.Windows.Navigation;
 using Microsoft.Phone.Controls;
 using Microsoft.Phone.Shell;
 using Microsoft.Phone.Tasks;
-using VideoResult = WP7GapClassLib.PhoneGap.UI.VideoCaptureTask.VideoResult;
+using VideoResult = WP7GapClassLib.Cordova.UI.VideoCaptureTask.VideoResult;
 
-namespace WP7GapClassLib.PhoneGap.UI
+namespace WP7GapClassLib.Cordova.UI
 {
     public partial class VideoRecorder : PhoneApplicationPage
     {

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/accelerometer.js
----------------------------------------------------------------------
diff --git a/framework/js/accelerometer.js b/framework/js/accelerometer.js
index 4f13e7d..930d5ce 100644
--- a/framework/js/accelerometer.js
+++ b/framework/js/accelerometer.js
@@ -12,9 +12,9 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("accelerometer")) 
+if (!Cordova.hasResource("accelerometer")) 
 {
-PhoneGap.addResource("accelerometer");
+Cordova.addResource("accelerometer");
 
 /** @constructor */
 var Acceleration = function(x, y, z) {
@@ -79,7 +79,7 @@ Accelerometer.prototype.getCurrentAcceleration = function(successCallback, error
 	}
 
     // Get acceleration
-    PhoneGap.exec(onSuccess, onError, "Accelerometer", "getAcceleration",options);
+    Cordova.exec(onSuccess, onError, "Accelerometer", "getAcceleration",options);
 };
 
 
@@ -116,14 +116,14 @@ Accelerometer.prototype.watchAcceleration = function(successCallback, errorCallb
         errorCallback(err);
     }
 
-    var id = PhoneGap.createUUID();
+    var id = Cordova.createUUID();
 
     var params = new Object();
     params.id = id;
     // Default interval (10 sec)
     params.frequency = (options && options.frequency) ? options.frequency : 10000;
 
-    PhoneGap.exec(onSuccess, onError, "Accelerometer", "startWatch", params);
+    Cordova.exec(onSuccess, onError, "Accelerometer", "startWatch", params);
 
     return id; 
 };
@@ -135,10 +135,10 @@ Accelerometer.prototype.watchAcceleration = function(successCallback, errorCallb
  */
 Accelerometer.prototype.clearWatch = function(id) {
 
-    PhoneGap.exec(null, null, "Accelerometer", "stopWatch", { id: id });
+    Cordova.exec(null, null, "Accelerometer", "stopWatch", { id: id });
 };
 
-PhoneGap.onPhoneGapInit.subscribeOnce(
+Cordova.onCordovaInit.subscribeOnce(
 function()
 {
     if (!navigator.accelerometer) 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/battery.js
----------------------------------------------------------------------
diff --git a/framework/js/battery.js b/framework/js/battery.js
index a606f4e..0285101 100644
--- a/framework/js/battery.js
+++ b/framework/js/battery.js
@@ -12,11 +12,11 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("battery")) {
+if (!Cordova.hasResource("battery")) {
 
-PhoneGap.addResource("battery");
+Cordova.addResource("battery");
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
 
 	navigator.battery = navigator.battery || 
 	{

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/camera.js
----------------------------------------------------------------------
diff --git a/framework/js/camera.js b/framework/js/camera.js
index 515a8c1..f11e1ea 100644
--- a/framework/js/camera.js
+++ b/framework/js/camera.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("camera")) {
-PhoneGap.addResource("camera");
+if (!Cordova.hasResource("camera")) {
+Cordova.addResource("camera");
 
 /**
  * This class provides access to the device camera.
@@ -140,10 +140,10 @@ Camera.prototype.getPicture = function(successCallback, errorCallback, options)
 //        }
 //    }
 
-    PhoneGap.exec(successCallback, errorCallback, "Camera", "getPicture", this.options);
+    Cordova.exec(successCallback, errorCallback, "Camera", "getPicture", this.options);
 };
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
     if (typeof navigator.camera === "undefined") {
         navigator.camera = new Camera();
     }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/capture.js
----------------------------------------------------------------------
diff --git a/framework/js/capture.js b/framework/js/capture.js
index 8943b32..ef5d681 100644
--- a/framework/js/capture.js
+++ b/framework/js/capture.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("capture")) {
-PhoneGap.addResource("capture");
+if (!Cordova.hasResource("capture")) {
+Cordova.addResource("capture");
 	
 /**
  * Represents a single file.
@@ -39,7 +39,7 @@ var MediaFile = function(name, fullPath, type, lastModifiedDate, size){
  * @param {Function} errorCB
  */
 MediaFile.prototype.getFormatData = function(successCallback, errorCallback){
-	PhoneGap.exec(successCallback, errorCallback, "Capture", "getFormatData", {fullPath: this.fullPath, type: this.type});
+	Cordova.exec(successCallback, errorCallback, "Capture", "getFormatData", {fullPath: this.fullPath, type: this.type});
 };
 
 
@@ -50,7 +50,7 @@ MediaFile.prototype.getFormatData = function(successCallback, errorCallback){
  * @param {Function} errorCB
  */
 MediaFile.prototype.play = function(successCallback, errorCallback){
-	PhoneGap.exec(successCallback, errorCallback, "Capture", "play", this);
+	Cordova.exec(successCallback, errorCallback, "Capture", "play", this);
 };
 
 
@@ -102,7 +102,7 @@ var Capture = function(){
  * @param {CaptureAudioOptions} options
  */
 Capture.prototype.captureAudio = function(successCallback, errorCallback, options){
-	PhoneGap.exec(successCallback, errorCallback, "Capture", "captureAudio", options);
+	Cordova.exec(successCallback, errorCallback, "Capture", "captureAudio", options);
 };
 
 /**
@@ -113,7 +113,7 @@ Capture.prototype.captureAudio = function(successCallback, errorCallback, option
  * @param {CaptureImageOptions} options
  */
 Capture.prototype.captureImage = function (successCallback, errorCallback, options) {
-    PhoneGap.exec(successCallback, errorCallback, "Capture", "captureImage", options);
+    Cordova.exec(successCallback, errorCallback, "Capture", "captureImage", options);
 };
 
 /**
@@ -124,7 +124,7 @@ Capture.prototype.captureImage = function (successCallback, errorCallback, optio
  * @param {CaptureVideoOptions} options
  */
 Capture.prototype.captureVideo = function(successCallback, errorCallback, options){
-	PhoneGap.exec(successCallback, errorCallback, "Capture", "captureVideo", options);
+	Cordova.exec(successCallback, errorCallback, "Capture", "captureVideo", options);
 };
 
 /**
@@ -194,7 +194,7 @@ var CaptureAudioOptions = function(){
 	// The selected audio mode. Must match with one of the elements in supportedAudioModes array.
 	this.mode = null;
 };
-PhoneGap.onPhoneGapInit.subscribeOnce(function () {
+Cordova.onCordovaInit.subscribeOnce(function () {
 	if (typeof navigator.device === "undefined") {
 		navigator.device = window.device = new Device();
 	}

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/compass.js
----------------------------------------------------------------------
diff --git a/framework/js/compass.js b/framework/js/compass.js
index 5754cf1..1408a6e 100644
--- a/framework/js/compass.js
+++ b/framework/js/compass.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("compass")) {
-PhoneGap.addResource("compass");
+if (!Cordova.hasResource("compass")) {
+Cordova.addResource("compass");
 
 /**
  * This class provides access to device Compass data.
@@ -77,7 +77,7 @@ Compass.prototype.getCurrentHeading = function(successCallback, errorCallback, o
 		}
 	
 		// Get heading
-		PhoneGap.exec(onSuccess, onError, "Compass", "getHeading", []);
+		Cordova.exec(onSuccess, onError, "Compass", "getHeading", []);
 	}
 	else
 	{
@@ -127,13 +127,13 @@ Compass.prototype.watchHeading= function(successCallback, errorCallback, options
 			errorCallback(err);
 		}
 	
-		var id = PhoneGap.createUUID();
+		var id = Cordova.createUUID();
 	
 		var params = {id:id,
 					  frequency:((options && options.frequency) ? options.frequency : 100)};
 	
 	
-		PhoneGap.exec(onSuccess, onError, "Compass", "startWatch", params);
+		Cordova.exec(onSuccess, onError, "Compass", "startWatch", params);
 	
 		return id; 
 	}
@@ -157,11 +157,11 @@ Compass.prototype.watchHeading= function(successCallback, errorCallback, options
  */
 Compass.prototype.clearWatch = function(id) {
 
-	PhoneGap.exec(null, null, "Compass", "stopWatch", { id: id });
+	Cordova.exec(null, null, "Compass", "stopWatch", { id: id });
 
 };
 
-PhoneGap.onPhoneGapInit.subscribeOnce(
+Cordova.onCordovaInit.subscribeOnce(
 function()
 {
     if (!navigator.compass) 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/contact.js
----------------------------------------------------------------------
diff --git a/framework/js/contact.js b/framework/js/contact.js
index 8e6a81c..5f19c50 100644
--- a/framework/js/contact.js
+++ b/framework/js/contact.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("contact")) {
-PhoneGap.addResource("contact");
+if (!Cordova.hasResource("contact")) {
+Cordova.addResource("contact");
 
 /**
 * Contains information about a single contact.
@@ -89,7 +89,7 @@ Contact.prototype.remove = function(successCB, errorCB)
     }
     else 
 	{
-        PhoneGap.exec(successCB, errorCB, "Contacts", "remove",this.id);
+        Cordova.exec(successCB, errorCB, "Contacts", "remove",this.id);
     }
 };
 
@@ -99,7 +99,7 @@ Contact.prototype.remove = function(successCB, errorCB)
 * @return copy of this Contact
 */
 Contact.prototype.clone = function() {
-    var clonedContact = PhoneGap.safeClone(this);
+    var clonedContact = Cordova.safeClone(this);
     var i;
     clonedContact.id = null;
     clonedContact.rawId = null;
@@ -135,7 +135,7 @@ Contact.prototype.save = function(successCB, errorCB)
 			successCB(self);
 		},0);
 	}
-    PhoneGap.exec(onSuccess, errorCB, "Contacts", "save", this);
+    Cordova.exec(onSuccess, errorCB, "Contacts", "save", this);
 };
 
 /**
@@ -255,7 +255,7 @@ Contacts.prototype.find = function(fields, successCB, errorCB, options) {
 				successCB(res);
 			},0);
 		}
-        PhoneGap.exec(onSuccess, errorCB, "Contacts", "search", {"fields":fields,"options":options});        
+        Cordova.exec(onSuccess, errorCB, "Contacts", "search", {"fields":fields,"options":options});        
     }
 };
 
@@ -309,7 +309,7 @@ var ContactFindOptions = function(filter, multiple) {
 /**
  * Add the contact interface into the browser.
  */
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
     if(typeof navigator.contacts === "undefined") {
         navigator.contacts = new Contacts();
     }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/debugConsole.js
----------------------------------------------------------------------
diff --git a/framework/js/debugConsole.js b/framework/js/debugConsole.js
index 4eef34c..93c5dff 100644
--- a/framework/js/debugConsole.js
+++ b/framework/js/debugConsole.js
@@ -1,5 +1,5 @@
 /*
- * PhoneGap is available under *either* the terms of the modified BSD license *or* the
+ * Cordova is available under *either* the terms of the modified BSD license *or* the
  * MIT License (2008). See http://opensource.org/licenses/alphabetical for full text.
  *
  * Copyright (c) 2005-2010, Nitobi Software Inc.
@@ -7,19 +7,19 @@
  * Copyright (c) 2011, Microsoft Corporation
  */
 
-if (!PhoneGap.hasResource("debugConsole")) {
-PhoneGap.addResource("debugConsole");
+if (!Cordova.hasResource("debugConsole")) {
+Cordova.addResource("debugConsole");
 
 var debugConsole = 
 {
 	log:function(msg){
-		PhoneGap.exec(null,null,"DebugConsole","log",msg);
+		Cordova.exec(null,null,"DebugConsole","log",msg);
 	},
 	warn:function(msg){
-		PhoneGap.exec(null,null,"DebugConsole","warn",msg);
+		Cordova.exec(null,null,"DebugConsole","warn",msg);
 	},
 	error:function(msg){
-		PhoneGap.exec(null,null,"DebugConsole","error",msg);
+		Cordova.exec(null,null,"DebugConsole","error",msg);
 	}	
 };
 
@@ -54,7 +54,7 @@ window.onerror=function(e)
 
 
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
 	navigator.debugConsole = debugConsole;
 });
 

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/device.js
----------------------------------------------------------------------
diff --git a/framework/js/device.js b/framework/js/device.js
index 74756ca..2c13829 100644
--- a/framework/js/device.js
+++ b/framework/js/device.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("device")) {
-PhoneGap.addResource("device");
+if (!Cordova.hasResource("device")) {
+Cordova.addResource("device");
 
 /**
  * This represents the mobile device, and provides properties for inspecting the model, version, UUID of the
@@ -21,7 +21,7 @@ PhoneGap.addResource("device");
  * @constructor
  */
 var Device = function() {
-    this.available = PhoneGap.available;
+    this.available = Cordova.available;
     this.platform = null;
     this.version = null;
     this.name = null;
@@ -40,11 +40,11 @@ var Device = function() {
             me.uuid = info.uuid;
             me.phonegap = info.phonegap;
 
-            PhoneGap.onPhoneGapInfoReady.fire();
+            Cordova.onCordovaInfoReady.fire();
         },
         function(e) {
             me.available = false;
-            console.log("Error initializing PhoneGap: " + e);
+            console.log("Error initializing Cordova: " + e);
         });
 };
 
@@ -69,10 +69,10 @@ Device.prototype.getInfo = function(successCallback, errorCallback) {
     }
 
     // Get info
-    PhoneGap.exec(successCallback, errorCallback, "Device", "Get");
+    Cordova.exec(successCallback, errorCallback, "Device", "Get");
 };
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
     if (typeof navigator.device === "undefined") {
         navigator.device = window.device = new Device();
     }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/file.js
----------------------------------------------------------------------
diff --git a/framework/js/file.js b/framework/js/file.js
index 5be9bf1..9726cde 100644
--- a/framework/js/file.js
+++ b/framework/js/file.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("file")) {
-PhoneGap.addResource("file");
+if (!Cordova.hasResource("file")) {
+Cordova.addResource("file");
 
 /**
  * Represents a single file.
@@ -67,34 +67,34 @@ FileMgr.prototype.getFileBasePaths = function() {
 };
 
 FileMgr.prototype.testFileExists = function(fileName, successCallback, errorCallback) {
-    return PhoneGap.exec(successCallback, errorCallback, "File", "testFileExists", {fileName: fileName});
+    return Cordova.exec(successCallback, errorCallback, "File", "testFileExists", {fileName: fileName});
 };
 
 FileMgr.prototype.testDirectoryExists = function(dirName, successCallback, errorCallback) {
-    return PhoneGap.exec(successCallback, errorCallback, "File", "testDirectoryExists", {dirName: dirName});
+    return Cordova.exec(successCallback, errorCallback, "File", "testDirectoryExists", {dirName: dirName});
 };
 
 FileMgr.prototype.getFreeDiskSpace = function(successCallback, errorCallback) {
-    return PhoneGap.exec(successCallback, errorCallback, "File", "getFreeDiskSpace");
+    return Cordova.exec(successCallback, errorCallback, "File", "getFreeDiskSpace");
 };
 
 FileMgr.prototype.write = function(fileName, data, position, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "write", {fileName: fileName, data: data, position: position});
+    Cordova.exec(successCallback, errorCallback, "File", "write", {fileName: fileName, data: data, position: position});
 };
 
 FileMgr.prototype.truncate = function(fileName, size, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "truncate", {fileName: fileName, size: size});
+    Cordova.exec(successCallback, errorCallback, "File", "truncate", {fileName: fileName, size: size});
 };
 
 FileMgr.prototype.readAsText = function(fileName, encoding, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "readAsText", {fileName: fileName, encoding: encoding});
+    Cordova.exec(successCallback, errorCallback, "File", "readAsText", {fileName: fileName, encoding: encoding});
 };
 
 FileMgr.prototype.readAsDataURL = function(fileName, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "readAsDataURL", {fileName: fileName});
+    Cordova.exec(successCallback, errorCallback, "File", "readAsDataURL", {fileName: fileName});
 };
 
-PhoneGap.addConstructor(function() {
+Cordova.addConstructor(function() {
     if (typeof navigator.fileMgr === "undefined") {
         navigator.fileMgr = new FileMgr();
     }
@@ -669,7 +669,7 @@ var DirectoryReader = function(fullPath){
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryReader.prototype.readEntries = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "readEntries", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "readEntries", {fullPath: this.fullPath});
 };
 
 /**
@@ -699,7 +699,7 @@ var DirectoryEntry = function() {
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.copyTo = function(parent, newName, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "copyTo", {fullPath: this.fullPath, parent:parent, newName: newName});
+    Cordova.exec(successCallback, errorCallback, "File", "copyTo", {fullPath: this.fullPath, parent:parent, newName: newName});
 };
 
 /**
@@ -709,7 +709,7 @@ DirectoryEntry.prototype.copyTo = function(parent, newName, successCallback, err
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.getMetadata = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getMetadata", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "getMetadata", {fullPath: this.fullPath});
 };
 
 /**
@@ -719,7 +719,7 @@ DirectoryEntry.prototype.getMetadata = function(successCallback, errorCallback)
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.getParent = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getParent", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "getParent", {fullPath: this.fullPath});
 };
 
 /**
@@ -731,7 +731,7 @@ DirectoryEntry.prototype.getParent = function(successCallback, errorCallback) {
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.moveTo = function(parent, newName, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "moveTo", {fullPath: this.fullPath, parent: parent, newName: newName});
+    Cordova.exec(successCallback, errorCallback, "File", "moveTo", {fullPath: this.fullPath, parent: parent, newName: newName});
 };
 
 /**
@@ -741,7 +741,7 @@ DirectoryEntry.prototype.moveTo = function(parent, newName, successCallback, err
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.remove = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "remove", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "remove", {fullPath: this.fullPath});
 };
 
 /**
@@ -771,7 +771,7 @@ DirectoryEntry.prototype.createReader = function(successCallback, errorCallback)
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.getDirectory = function (path, options, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getDirectory", { fullPath: this.fullPath, path: path, options: options });
+    Cordova.exec(successCallback, errorCallback, "File", "getDirectory", { fullPath: this.fullPath, path: path, options: options });
 };
 
 /**
@@ -783,7 +783,7 @@ DirectoryEntry.prototype.getDirectory = function (path, options, successCallback
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.getFile = function (path, options, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getFile", { fullPath: this.fullPath, path: path, options: options });
+    Cordova.exec(successCallback, errorCallback, "File", "getFile", { fullPath: this.fullPath, path: path, options: options });
 };
 
 /**
@@ -793,7 +793,7 @@ DirectoryEntry.prototype.getFile = function (path, options, successCallback, err
  * @param {Function} errorCallback is called with a FileError
  */
 DirectoryEntry.prototype.removeRecursively = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "removeRecursively", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "removeRecursively", {fullPath: this.fullPath});
 };
 
 /**
@@ -823,7 +823,7 @@ var FileEntry = function() {
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.copyTo = function(parent, newName, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "copyTo", {fullPath: this.fullPath, parent: parent, newName: newName});
+    Cordova.exec(successCallback, errorCallback, "File", "copyTo", {fullPath: this.fullPath, parent: parent, newName: newName});
 };
 
 /**
@@ -833,7 +833,7 @@ FileEntry.prototype.copyTo = function(parent, newName, successCallback, errorCal
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.getMetadata = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getMetadata", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "getMetadata", {fullPath: this.fullPath});
 };
 
 /**
@@ -843,7 +843,7 @@ FileEntry.prototype.getMetadata = function(successCallback, errorCallback) {
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.getParent = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getParent", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "getParent", {fullPath: this.fullPath});
 };
 
 /**
@@ -855,7 +855,7 @@ FileEntry.prototype.getParent = function(successCallback, errorCallback) {
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.moveTo = function(parent, newName, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "moveTo", {fullPath: this.fullPath, parent: parent, newName: newName});
+    Cordova.exec(successCallback, errorCallback, "File", "moveTo", {fullPath: this.fullPath, parent: parent, newName: newName});
 };
 
 /**
@@ -865,7 +865,7 @@ FileEntry.prototype.moveTo = function(parent, newName, successCallback, errorCal
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.remove = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "remove", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "remove", {fullPath: this.fullPath});
 };
 
 /**
@@ -909,7 +909,7 @@ FileEntry.prototype.createWriter = function (successCallback, errorCallback) {
  * @param {Function} errorCallback is called with a FileError
  */
 FileEntry.prototype.file = function(successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "getFileMetadata", {fullPath: this.fullPath});
+    Cordova.exec(successCallback, errorCallback, "File", "getFileMetadata", {fullPath: this.fullPath});
 };
 
 /** @constructor */
@@ -938,7 +938,7 @@ LocalFileSystem.prototype.requestFileSystem = function(type, size, successCallba
         }
     }
     else {
-        PhoneGap.exec(successCallback, errorCallback, "File", "requestFileSystem", {type: type, size: size});
+        Cordova.exec(successCallback, errorCallback, "File", "requestFileSystem", {type: type, size: size});
     }
 };
 
@@ -949,7 +949,7 @@ LocalFileSystem.prototype.requestFileSystem = function(type, size, successCallba
  * @param {Function} errorCallback is called with a FileError
  */
 LocalFileSystem.prototype.resolveLocalFileSystemURI = function(uri, successCallback, errorCallback) {
-    PhoneGap.exec(successCallback, errorCallback, "File", "resolveLocalFileSystemURI", {uri: uri});
+    Cordova.exec(successCallback, errorCallback, "File", "resolveLocalFileSystemURI", {uri: uri});
 };
 
 /**
@@ -1036,7 +1036,7 @@ LocalFileSystem.prototype._castDate = function (pluginResult) {
 /**
  * Add the FileSystem interface into the browser.
  */
-PhoneGap.onPhoneGapInit.subscribeOnce(function () {
+Cordova.onCordovaInit.subscribeOnce(function () {
     var pgLocalFileSystem = new LocalFileSystem();
 	// Needed for cast methods
     if(typeof window.localFileSystem == "undefined") window.localFileSystem  = pgLocalFileSystem;

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/filetransfer.js
----------------------------------------------------------------------
diff --git a/framework/js/filetransfer.js b/framework/js/filetransfer.js
index 2d218ec..cc64555 100644
--- a/framework/js/filetransfer.js
+++ b/framework/js/filetransfer.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("filetransfer")) {
-PhoneGap.addResource("filetransfer");
+if (!Cordova.hasResource("filetransfer")) {
+Cordova.addResource("filetransfer");
 
 /**
  * FileTransfer uploads a file to a remote server.
@@ -81,7 +81,7 @@ FileTransfer.prototype.upload = function(filePath, server, successCallback, erro
     options.filePath = filePath;
     options.server = server;
 
-    PhoneGap.exec(successCallback, errorCallback, 'FileTransfer', 'upload', options);
+    Cordova.exec(successCallback, errorCallback, 'FileTransfer', 'upload', options);
 };
 
 /**

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/media.js
----------------------------------------------------------------------
diff --git a/framework/js/network.js b/framework/js/network.js
index a3e6a98..3ab9337 100644
--- a/framework/js/network.js
+++ b/framework/js/network.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("network")) {
-PhoneGap.addResource("network");
+if (!Cordova.hasResource("network")) {
+Cordova.addResource("network");
 
 /**
  * This class contains information about the current network Connection.
@@ -35,8 +35,8 @@ var Connection = function()
                 // set a timer if still offline at the end of timer send the offline event
                 me._timer = setTimeout(function(){
                     me.type = type;
-					//console.log("PhoneGap.fireEvent::offline");
-                    PhoneGap.fireEvent(document,'offline');
+					//console.log("Cordova.fireEvent::offline");
+                    Cordova.fireEvent(document,'offline');
                     me._timer = null;
                     }, me.timeout);
             } else {
@@ -46,16 +46,16 @@ var Connection = function()
                     me._timer = null;
                 }
                 me.type = type;
-				//console.log("PhoneGap.fireEvent::online " + me.type);
-                PhoneGap.fireEvent(document,'online');
+				//console.log("Cordova.fireEvent::online " + me.type);
+                Cordova.fireEvent(document,'online');
             }
             
             // should only fire this once
             if (me._firstRun) 
 			{
                 me._firstRun = false;
-				//console.log("onPhoneGapConnectionReady");
-                PhoneGap.onPhoneGapConnectionReady.fire();
+				//console.log("onCordovaConnectionReady");
+                Cordova.onCordovaConnectionReady.fire();
             }            
         },
         function(e) {
@@ -80,11 +80,11 @@ Connection.CELL = "cellular";
  */
 Connection.prototype.getInfo = function(successCallback, errorCallback) {
     // Get info
-    PhoneGap.exec(successCallback, errorCallback, "Connection", "getConnectionInfo", []);
+    Cordova.exec(successCallback, errorCallback, "Connection", "getConnectionInfo", []);
 };
 
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
 
 	navigator.network = navigator.network || {};
     if (typeof navigator.network.connection === "undefined") {

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/notification.js
----------------------------------------------------------------------
diff --git a/framework/js/notification.js b/framework/js/notification.js
index 78b79b1..a36a636 100644
--- a/framework/js/notification.js
+++ b/framework/js/notification.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("notification")) {
-PhoneGap.addResource("notification");
+if (!Cordova.hasResource("notification")) {
+Cordova.addResource("notification");
 
 /**
  * This class provides access to notifications on the device.
@@ -34,7 +34,7 @@ Notification.prototype.alert = function(message, completeCallback, title, button
 {
     var _title = (title || "Alert");
     var _buttonLabels = (buttonLabel || "OK");
-    PhoneGap.exec(completeCallback, null, "Notification", "alert",{"message":message,"title":_title,"buttonLabels":_buttonLabels});
+    Cordova.exec(completeCallback, null, "Notification", "alert",{"message":message,"title":_title,"buttonLabels":_buttonLabels});
 };
 
 /**
@@ -50,21 +50,21 @@ Notification.prototype.confirm = function(message, resultCallback, title, button
 {
     var _title = (title || "Confirm");
     var _buttonLabels = (buttonLabels || "OK,Cancel");
-    PhoneGap.exec(resultCallback, null, "Notification", "confirm", {'message':message,"title":_title,"buttonLabels":_buttonLabels});
+    Cordova.exec(resultCallback, null, "Notification", "confirm", {'message':message,"title":_title,"buttonLabels":_buttonLabels});
 };
 
 /**
  * Start spinning the activity indicator on the statusbar
  */
 Notification.prototype.activityStart = function() {
-    PhoneGap.exec(null, null, "Notification", "activityStart", ["Busy","Please wait..."]);
+    Cordova.exec(null, null, "Notification", "activityStart", ["Busy","Please wait..."]);
 };
 
 /**
  * Stop spinning the activity indicator on the statusbar, if it's currently spinning
  */
 Notification.prototype.activityStop = function() {
-    PhoneGap.exec(null, null, "Notification", "activityStop", []);
+    Cordova.exec(null, null, "Notification", "activityStop", []);
 };
 
 /**
@@ -74,7 +74,7 @@ Notification.prototype.activityStop = function() {
  * @param {String} message      Message to display in the dialog.
  */
 Notification.prototype.progressStart = function(title, message) {
-    PhoneGap.exec(null, null, "Notification", "progressStart", [title, message]);
+    Cordova.exec(null, null, "Notification", "progressStart", [title, message]);
 };
 
 /**
@@ -83,14 +83,14 @@ Notification.prototype.progressStart = function(title, message) {
  * @param {Number} value         0-100
  */
 Notification.prototype.progressValue = function(value) {
-    PhoneGap.exec(null, null, "Notification", "progressValue", [value]);
+    Cordova.exec(null, null, "Notification", "progressValue", [value]);
 };
 
 /**
  * Close the progress dialog.
  */
 Notification.prototype.progressStop = function() {
-    PhoneGap.exec(null, null, "Notification", "progressStop", []);
+    Cordova.exec(null, null, "Notification", "progressStop", []);
 };
 
 /**
@@ -110,7 +110,7 @@ Notification.prototype.blink = function(count, colour) {
  */
 Notification.prototype.vibrate = function(mills) 
 {
-    PhoneGap.exec(null, null, "Notification", "vibrate", {duration:mills});
+    Cordova.exec(null, null, "Notification", "vibrate", {duration:mills});
 };
 
 /**
@@ -122,10 +122,10 @@ Notification.prototype.vibrate = function(mills)
 Notification.prototype.beep = function(repeatCount) 
 {
 	var count = repeatCount|| 1;
-    PhoneGap.exec(null, null, "Notification", "beep", count);
+    Cordova.exec(null, null, "Notification", "beep", count);
 };
 
-PhoneGap.onPhoneGapInit.subscribeOnce(function() {
+Cordova.onCordovaInit.subscribeOnce(function() {
     if (typeof navigator.notification === "undefined") {
         navigator.notification = new Notification();
     }
diff --git a/framework/PhoneGap/Commands/Device.cs b/framework/PhoneGap/Commands/Device.cs
index e88146c..055cbca 100644
--- a/framework/PhoneGap/Commands/Device.cs
+++ b/framework/PhoneGap/Commands/Device.cs
@@ -28,7 +28,7 @@ using System.Windows.Resources;
 using System.IO;
 using System.Diagnostics;
 
-namespace WP7GapClassLib.PhoneGap.Commands
+namespace WP7GapClassLib.Cordova.Commands
 {
     public class Device : BaseCommand
     {
@@ -60,7 +60,7 @@ namespace WP7GapClassLib.PhoneGap.Commands
         {
             get
             {
                 // TODO: should be able to dynamically read the PhoneGap version from somewhere...
                 return "1.4.1";
             }
         }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/Commands/File.cs
----------------------------------------------------------------------
@@ -60,7 +60,7 @@ namespace WP7GapClassLib.PhoneGap.Commands
             get
             {
-                // TODO: should be able to dynamically read the PhoneGap version from somewhere...
+                // TODO: should be able to dynamically read the Cordova version from somewhere...
                 return "1.4.1";
             }
diff --git a/framework/PhoneGap/PhoneGapCommandCall.cs b/framework/PhoneGap/PhoneGapCommandCall.cs
index 68e400e..8692472 100644
--- a/framework/PhoneGap/PhoneGapCommandCall.cs
+++ b/framework/PhoneGap/PhoneGapCommandCall.cs
@@ -24,12 +24,12 @@ using System.Windows.Media.Animation;
 using System.Windows.Shapes;
 using System.Linq;
 
-namespace WP7GapClassLib.PhoneGap
+namespace WP7GapClassLib.Cordova
 {
     /// <summary>
     /// Represents PhoneGap native command call: action callback, etc
     /// </summary>
-    public class PhoneGapCommandCall
+    public class CordovaCommandCall
     {
         public String Service {get; private set;}
         public String Action {get; private set;}
@@ -40,8 +40,8 @@ namespace WP7GapClassLib.PhoneGap
         /// Retrieves command call parameters and creates wrapper for them
         /// </summary>
         /// <param name="commandStr">Command string in the form 'service/action/callback/args'</param>
-        /// <returns>New class instance or null of string does not represent PhoneGap command</returns>
-        public static PhoneGapCommandCall Parse(string commandStr)
+        /// <returns>New class instance or null of string does not represent Cordova command</returns>
+        public static CordovaCommandCall Parse(string commandStr)
         {
             if (string.IsNullOrEmpty(commandStr))
             {
@@ -55,7 +55,7 @@ namespace WP7GapClassLib.PhoneGap
                 return null;
             }
 
-            PhoneGapCommandCall commandCallParameters = new PhoneGapCommandCall();
+            CordovaCommandCall commandCallParameters = new CordovaCommandCall();
 
             commandCallParameters.Service = split[0];
             commandCallParameters.Action = split[1];
@@ -64,7 +64,7 @@ namespace WP7GapClassLib.PhoneGap
 
             // sanity check for illegal names
             // was failing with ::
-            // PhoneGapCommandResult :: 1, Device1, {"status":1,"message":"{\"name\":\"XD.....
+            // CordovaCommandResult :: 1, Device1, {"status":1,"message":"{\"name\":\"XD.....
             if (commandCallParameters.Service.IndexOfAny(new char[] { '@', ':', ',', '!', ' ' }) > -1)
             {
                 return null;
@@ -77,9 +77,9 @@ namespace WP7GapClassLib.PhoneGap
 
         /// <summary>
         /// Private ctr to disable class creation.
         /// New class instance must be initialized via PhoneGapCommandCall.Parse static method.
         /// </summary>
-        private PhoneGapCommandCall() { }
+        private CordovaCommandCall() { }
             
 
     }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/PhoneGap/PluginResult.cs
----------------------------------------------------------------------
@@ -24,12 +24,12 @@ using System.Windows.Media.Animation;
 {
     /// <summary>
-    /// Represents PhoneGap native command call: action callback, etc
+    /// Represents Cordova native command call: action callback, etc
     /// </summary>
@@ -77,9 +77,9 @@ namespace WP7GapClassLib.PhoneGap
         /// <summary>
         /// Private ctr to disable class creation.
-        /// New class instance must be initialized via PhoneGapCommandCall.Parse static method.
+        /// New class instance must be initialized via CordovaCommandCall.Parse static method.
         /// </summary>
diff --git a/framework/js/media.js b/framework/js/media.js
index adfc861..c6bca1c 100644
--- a/framework/js/media.js
+++ b/framework/js/media.js
@@ -12,8 +12,8 @@
 	limitations under the License.
 */
 
-if (!PhoneGap.hasResource("media")) {
-PhoneGap.addResource("media");
+if (!Cordova.hasResource("media")) {
+Cordova.addResource("media");
 
 /**
  * This class provides access to the device media, interfaces to both sound and video
@@ -55,8 +55,8 @@ var Media = function(src, successCallback, errorCallback, statusCallback, positi
         return;
     }
 
-    this.id = PhoneGap.createUUID();
-    PhoneGap.mediaObjects[this.id] = this;
+    this.id = Cordova.createUUID();
+    Cordova.mediaObjects[this.id] = this;
     this.src = src;
     this.successCallback = successCallback;
     this.errorCallback = errorCallback;
@@ -103,28 +103,28 @@ MediaError.MEDIA_ERR_STOP_STATE = 8;
  * Start or resume playing audio file.
  */
 Media.prototype.play = function() {
-    PhoneGap.exec(null, null, "Media", "startPlayingAudio", {id: this.id, src: this.src});
+    Cordova.exec(null, null, "Media", "startPlayingAudio", {id: this.id, src: this.src});
 };
 
 /**
  * Stop playing audio file.
  */
 Media.prototype.stop = function() {
-    return PhoneGap.exec(null, null, "Media", "stopPlayingAudio", {id: this.id});
+    return Cordova.exec(null, null, "Media", "stopPlayingAudio", {id: this.id});
 };
 
 /**
  * Seek or jump to a new time in the track..
  */
 Media.prototype.seekTo = function(milliseconds) {
-    PhoneGap.exec(null, null, "Media", "seekToAudio", {id: this.id, milliseconds: milliseconds});
+    Cordova.exec(null, null, "Media", "seekToAudio", {id: this.id, milliseconds: milliseconds});
 };
 
 /**
  * Pause playing audio file.
  */
 Media.prototype.pause = function() {
-    PhoneGap.exec(null, null, "Media", "pausePlayingAudio", {id: this.id});
+    Cordova.exec(null, null, "Media", "pausePlayingAudio", {id: this.id});
 };
 
 /**
@@ -141,42 +141,42 @@ Media.prototype.getDuration = function() {
  * Get position of audio.
  */
 Media.prototype.getCurrentPosition = function(success, fail) {
-    PhoneGap.exec(success, fail, "Media", "getCurrentPositionAudio", {id: this.id});
+    Cordova.exec(success, fail, "Media", "getCurrentPositionAudio", {id: this.id});
 };
 
 /**
  * Start recording audio file.
  */
 Media.prototype.startRecord = function() {
-    PhoneGap.exec(null, null, "Media", "startRecordingAudio", {id: this.id, src: this.src});
+    Cordova.exec(null, null, "Media", "startRecordingAudio", {id: this.id, src: this.src});
 };
 
 /**
  * Stop recording audio file.
  */
 Media.prototype.stopRecord = function() {
-    PhoneGap.exec(null, null, "Media", "stopRecordingAudio", {id: this.id});
+    Cordova.exec(null, null, "Media", "stopRecordingAudio", {id: this.id});
 };
 
 /**
  * Release the resources.
  */
 Media.prototype.release = function() {
-    PhoneGap.exec(null, null, "Media", "release", {id: this.id});
+    Cordova.exec(null, null, "Media", "release", {id: this.id});
 };
 
 /**
  * List of media objects.
  * PRIVATE
  */
-PhoneGap.mediaObjects = {};
+Cordova.mediaObjects = {};
 
 /**
  * Object that receives native callbacks.
  * PRIVATE
  * @constructor
  */
-PhoneGap.Media = function() {};
+Cordova.Media = function() {};
 
 /**
  * Get the media object.
@@ -184,8 +184,8 @@ PhoneGap.Media = function() {};
  *
  * @param id            The media object id (string)
  */
-PhoneGap.Media.getMediaObject = function(id) {
-    return PhoneGap.mediaObjects[id];
+Cordova.Media.getMediaObject = function(id) {
+    return Cordova.mediaObjects[id];
 };
 
 /**
@@ -196,8 +196,8 @@ PhoneGap.Media.getMediaObject = function(id) {
  * @param status        The status code (int)
  * @param msg           The status message (string)
  */
-PhoneGap.Media.onStatus = function(id, msg, value) {
-    var media = PhoneGap.mediaObjects[id];
+Cordova.Media.onStatus = function(id, msg, value) {
+    var media = Cordova.mediaObjects[id];
     // If state update
     if (msg === Media.MEDIA_STATE) {
         if (value === Media.MEDIA_STOPPED) {
@@ -222,11 +222,11 @@ PhoneGap.Media.onStatus = function(id, msg, value) {
     }
 };
 
 // We need special proxy to invoke PhoneGap.Media.onStatus (method is not visible in other case)
 // http://stackoverflow.com/questions/7322420/calling-javascript-object-method-using-webbrowser-document-invokescript
-PhoneGapMediaonStatus = function (args) {
+CordovaMediaonStatus = function (args) {
     var res = JSON.parse(args);
-    PhoneGap.Media.onStatus(res.id, res.msg, res.value);
+    Cordova.Media.onStatus(res.id, res.msg, res.value);
 }
 
 }

http://git-wip-us.apache.org/repos/asf/incubator-cordova-wp7/blob/552bc14a/framework/js/network.js
----------------------------------------------------------------------
@@ -222,11 +222,11 @@ PhoneGap.Media.onStatus = function(id, msg, value) {
 };
 
-// We need special proxy to invoke PhoneGap.Media.onStatus (method is not visible in other case)
+// We need special proxy to invoke Cordova.Media.onStatus (method is not visible in other case)
 // http://stackoverflow.com/questions/7322420/calling-javascript-object-method-using-webbrowser-document-invokescript